List
----
List manipulation functions.

**Functions**:

- ensure
- setDiff
- unique
- getSlot
- assocKeys

.. dropdown:: List.ils sourcecode

    .. literalinclude:: ../_static/src/List.ils
       :language: none
       :linenos:
